@@ -7,7 +7,7 @@ use UNIVERSAL::Object;
 use Data::GUID;
 use Autoload::AUTOCAN;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use feature qw/switch/;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
@@ -87,28 +87,11 @@ BEGIN {
 sub AUTOCAN {
     my ( $self, $meth ) = @_;
     return if $meth =~ /BUILD|DEMOLISH/;
-    my $element = $self->_look_for($meth, ['name']);
+    my $element = $self->get_element($meth, ['name']);
     return sub { $element } if $element;
     die "AUTOCAN: ${meth} cannot be found";
 }
 
-sub _look_for {
-    for my $ele (qw/data children before_element after_element/) {
-        next unless is_arrayref($_[0]->{$ele});
-        for my $e ( @{$_[0]->{$ele}} ) {
-            next unless is_blessed_ref($e);
-            for ( @{ $_[2] } ) {
-                my $has = sprintf 'has_%s', $_;
-                $e->$has and $e->$_ =~ m/$_[1]/
-                    and return $e;
-            }
-            my $found = $e->_look_for( $_[1], $_[2] );
-            return $found if $found;
-        }
-    }
-    return undef;
-}
-
 sub BUILDARGS {
     my ( $self, $args ) = @_;
 
@@ -216,9 +199,58 @@ sub set {
     return $_[0];
 }
 
+sub get_element {
+    for my $ele (qw/before_element data children after_element/) {
+        next unless is_arrayref($_[0]->{$ele});
+        for my $e ( @{$_[0]->{$ele}} ) {
+            next unless is_blessed_ref($e);
+            for ( @{ $_[2] } ) {
+                my $has = sprintf 'has_%s', $_;
+                $e->$has and $e->_attribute_value($_, $has) =~ m/$_[1]/
+                    and return $e;
+            }
+            my $found = $e->get_element( $_[1], $_[2] );
+            return $found if $found;
+        }
+    }
+    return undef;
+}
+
 sub get_element_by_id {
     is_scalarref(\$_[1]) or die "first param passed to get_element_by_id not a scalar";
-    return $_[0]->_look_for($_[1], ['id']);
+    return $_[0]->get_element($_[1], ['id']);
+}
+
+sub get_element_by_name {
+    is_scalarref(\$_[1]) or die "first param passed to get_element_by_name not a scalar";
+    return $_[0]->get_element($_[1], ['name']);
+}
+
+sub get_elements {
+    $_[3] //= [];
+    for my $ele (qw/before_element data children after_element/) {
+        next unless is_arrayref($_[0]->{$ele});
+        for my $e ( @{$_[0]->{$ele}} ) {
+            next unless is_blessed_ref($e);
+            for ( @{ $_[2] } ) {
+                my $has = sprintf 'has_%s', $_;
+                $e->$has and $e->_attribute_value($_, $has) =~ m/$_[1]/
+                    and push @{ $_[3] }, $e;
+            }
+            $e->get_elements( $_[1], $_[2], $_[3] );
+        }
+    }
+    return $_[3];
+}
+
+sub get_elements_by_class {
+    is_scalarref(\$_[1]) or die "first param passed to get_elements_by_class not a scalar";
+    return $_[0]->get_elements($_[1], ['class']);
+}
+
+sub get_elements_by_tag {
+    is_scalarref(\$_[1]) or die "first param passed to get_elements_by_tag not a scalar";
+    return $_[0]->get_elements($_[1], ['tag']);
 }
 
 sub _render_element {
@@ -275,7 +307,7 @@ Moonshine::Element - Build some more html.
 
 =head1 VERSION
 
-Version 0.09 
+Version 0.10 
 
 =head1 DESCRIPTION
 
@@ -383,21 +415,52 @@ is pushed in the after_element attribute.
         }
     );
 
+=head2 get_element
+
+Will always return the first element if one is found.
+
+    $self->get_element('find-me', ['id', 'name']);
+
 =head2 get_element_by_id
 
-Accepts an id and returns the element if found.
+Accepts a id and returns a element or undef.
 
     my $element = $base->get_element_by_id('find-me');
 
+=head2 get_element_by_name
+
+Accepts a name and returns a element or undef.
+
+    my $element = $base->get_element_by_name('findme');
+
+or..
+
+    $element->findme
+
+=head2 get_elements
+
+Returns ArrayRef of Elements.
+
+    $self->get_elements('found', ['class']);
+
+=head2 get_element_by_class
+
+Accepts a Scalar returns ArrayRef of Elements.
+
+    $self->get_elements_by_class('found');
+
+=head2 get_elements_by_tag
+
+Accepts a Scalar returns ArrayRef of Elements.
+
+    $self->get_elements_by_tag('table');
+
 =head2 render
 
 Render the Element as html.
 
     $base->render;
 
-All attributes set on an 'Element' will be rendered. There is currently no Attribute to Element
-validation.
-
 Html attributes can be HashRef's (keys sorted and values joined), ArrayRef's(joined), or just Scalars.
 
 =head1 AUTHOR
